const express = require('express');
const Tutor = require('../models/tutors');
const router = express.Router();

router.post('/register', async (req, res) => {
  try {
    const { tutorName, email, contactNumber, availability, experience, teachingGrade, knowledgeLevel } = req.body;

    const newTutor = new Tutor({
      tutorName,
      email,
      contactNumber,
      availability,
      experience,
      teachingGrade,
      knowledgeLevel,
    });

    const savedTutor = await newTutor.save();
    res.status(201).json(savedTutor);
  } catch (error) {
    res.status(500).json('Error while registering tutor. Please try again.');
  }
});

router.get('/getAllTutors', async (req, res) => {
  try {
    const tutors = await Tutor.find({});
    const sortedByCreationDate = tutors.sort((a, b) => b.createdAt - a.createdAt);
    res.json(sortedByCreationDate);
  } catch (error) {
    res.status(500).json('Error while fetching list of tutors. Please try again later.');
  }
});

router.get('/getTutorsByLevel/:level', async (req, res) => {
  const level = req.params.level;
  try {
    const tutors = await Tutor.find({ teachingGrade: level });
    const sortedByCreationDate = tutors.sort((a, b) => b.createdAt - a.createdAt);
    res.json(sortedByCreationDate);
  } catch (error) {
    res.status(500).json('Error while fetching tutors by level. Please try again later.');
  }
});

module.exports = router;
